// This file is part of Lx.
//
// Copyright 2003, 2004, Norman Gray (norman@astro.gla.ac.uk).
// Released under the terms of the GNU General Public Licence:
// see the file LICENCE for details.


package uk.me.nxg.lx;


/**
 * A class representing Lx version information.
 *
 * <p>This documentation is for version 0.5.3, of 2012 August 5.
 */
public class Version {
    private static final String versionStamp = "0.5.3";
    private static final String releaseDate = "2012 August 5";

    private Version() {
        // do nothing -- private constructor prevents instantiation
    }

    /**
     * Returns the version string.  Also includes the software release date.
     * @return the version string in a printable form.
     */
    public static String getVersion() {
        return "Lx " + versionStamp + ", released " + releaseDate;
    }

    /**
     * Returns the version as an integer.  The returned integer is
     * formed from the major version times one million, plus the minor
     * version times one thousand, plus any release number.  It
     * therefore increases monotonically with releases.
     *
     * @return the Lx version number encoded into an integer
     */
    public static int getVersionInteger() {
        java.util.regex.Pattern p = java.util.regex.Pattern.compile("\\d+");
        java.util.regex.Matcher m = p.matcher(versionStamp);
        int[] vnums = { 0, 0, 0 };
        for (int i=0; i<vnums.length; i++) {
            if (!m.find())
                break;
            vnums[i] = Integer.parseInt(m.group(), 10);
        }
        return vnums[0]*1000000 + vnums[1]*1000 + vnums[2];
    }
}
