package uk.me.nxg.lx.helpers;

import java.io.File;
import java.io.Writer;
import java.io.FileOutputStream;
import java.io.OutputStreamWriter;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.io.BufferedReader;

import junit.framework.Assert;
import junit.framework.TestCase;

public class TransformerTest
        extends TestCase {

    public TransformerTest(String name) {
        super(name);
    }

    private Writer fileWriter(File f) 
            throws java.io.FileNotFoundException {
        java.nio.charset.Charset utf8 = java.nio.charset.Charset.forName("UTF-8");
        return new OutputStreamWriter(new FileOutputStream(f), utf8);
    }

    public void testInclusion()
            throws Exception {
        File sourceFile =  File.createTempFile("TransformerTest", ".xml");
        File lxFile =      File.createTempFile("TransformerTest", ".lx");
        File includeFile = File.createTempFile("TransformerTest", ".inc");
        File outputFile =  File.createTempFile("TransformerTest", ".out");

        Writer fw = fileWriter(sourceFile);
        String content = "<document><el/></document>";
        fw.write(content, 0, content.length());
        fw.close();

        fw = fileWriter(lxFile);
        content = "(lx:namespace ((#f \"http://www.w3.org/1999/XSL/Transform\")) (stylesheet version: 1.0 (template match: /document (copy-of select: \"document('"
                + includeFile.toString() + "')\"))))";
        fw.write(content, 0, content.length());
        fw.close();

        fw = fileWriter(includeFile);
        // includes unicode characters: en-dash is 2013 and e-acute is 00e9
        content = "<foo>one\u2013two \u00e9clairs</foo>";
        fw.write(content, 0, content.length());
        fw.close();

        Transformer.doTransformation(sourceFile,
                                     lxFile,
                                     outputFile,
                                     Transformer.Outputs.XML,
                                     (java.util.Map)null,
                                     false);

        BufferedReader fr = new BufferedReader(new InputStreamReader(new FileInputStream(outputFile), "UTF-8"));
        StringBuffer sb = new StringBuffer();
        for (String l = fr.readLine(); l != null; l=fr.readLine())
            sb.append(l);
//         System.err.print("buffer: " + sb.toString() + " =");
//         byte[] stringbytes = sb.toString().getBytes("UTF-8");
//         for (byte b : stringbytes) {
//             System.err.format(" %x", b);
//         }
//         System.err.println();

        assertEquals("<?xml version=\"1.0\" encoding=\"UTF-8\"?><foo>one\u2013two \u00e9clairs</foo>",
                     sb.toString());


        // all OK -- get rid of the evidence
        sourceFile.deleteOnExit();
        lxFile.deleteOnExit();
        includeFile.deleteOnExit();
        outputFile.deleteOnExit();
    }
}
